@@ -68,14 +68,23 @@ function scan(as, msg, param, value) {
 	
 	// Test the response here, and make other requests as required
 	if (true) {	// Change to a test which detects the vulnerability
-		// raiseAlert(risk, int confidence, String name, String description, String uri, 
-		//		String param, String attack, String otherInfo, String solution, String evidence, 
-		//		int cweId, int wascId, HttpMessage msg)
 		// risk: 0: info, 1: low, 2: medium, 3: high
 		// confidence: 0: falsePositive, 1: low, 2: medium, 3: high, 4: confirmed
-		as.raiseAlert(1, 1, 'Active Vulnerability title', 'Full description', 
-		msg.getRequestHeader().getURI().toString(), 
-			param, 'Your attack', 'Any other info', 'The solution ', '', 'References', 0, 0, msg);
+		as.newAlert()
+			.setRisk(1)
+			.setConfidence(1)
+			.setName('Active Vulnerability title')
+			.setDescription('Full description')
+			.setParam(param)
+			.setAttack('Your attack')
+			.setEvidence('Evidence')
+			.setOtherInfo('Any other info')
+			.setSolution('The solution')
+			.setReference('References')
+			.setCweId(0)
+			.setWascId(0)
+			.setMessage(msg)
+			.raise();
 	}
 }
 
