@@ -1,12 +1,11 @@
 // The parseParameter function will typically be called for every page and 
-// the setParameter function is called by each active plugin to bundle specific attacks
+// the setParameter function is called by each active plugin to bundle specific attacks.
 
 // Note that new custom input vector scripts will initially be disabled
 // Right click the script in the Scripts tree and select "enable"  
 
-// The helper parameter leveraged within this variant provides access to the methods
-// in VariantCustom 
-// https://github.com/zaproxy/zaproxy/blob/develop/src/org/parosproxy/paros/core/scanner/VariantCustom.java
+// The helper parameter leveraged within this variant provides access to the methods in VariantCustom 
+// https://github.com/zaproxy/zaproxy/blob/main/zap/src/main/java/org/parosproxy/paros/core/scanner/VariantCustom.java
 
 var B64STATE = 'b64';
 var paramStates = [];
@@ -72,3 +71,43 @@ function setParameter(helper, msg, param, value, escaped) {
     //Set the parameters
     msg.getRequestHeader().getURI().setEscapedQuery(query);
 }
+
+/**
+ * Gets the name of the node to be used for the given {@code msg} in the Site Map. Returning null is
+ * taken to mean use the default name. This is currently the last element of the path (given in
+ * {@code nodeName}) followed by the url parameter names in brackets (if any) followed by the
+ * form parameter names in brackets (if any).
+ *
+ * @param helper a helper class as per parseParameters
+ * @param nodeName the last element of the path
+ * @param msg the message
+ * @return the name of the node to be used in the Site Map
+ */
+function getLeafName(helper, nodeName, msg) {
+	return null;
+}
+
+/**
+ * Returns the tree path elements for the given {@code message}. Returning null is taken to mean
+ * use the default methods for obtaining tree path elements.
+ * This will determine the position of this message in the sites tree.
+ *
+ * <p>By default the elements that are returned for the following URLs are:
+ *
+ * <ul>
+ *   <li><i>http://example.org/path/to/element?aa=bb&cc==dd</i> : ["path", "to", "element"]
+ *   <li><i>http://example.org/path/to/element</i> : ["path", "to", "element"]
+ *   <li><i>http://example.org/path/to/</i> : ["path", "to"]
+ *   <li><i>http://example.org/path/to</i> : ["path", "to"]
+ * </ul>
+ *
+ * @param helper a helper class as per parseParameters
+ * @param msg the message for which the tree path elements will be extracted from. This is an HttpMessage object.
+ * @return a {@code List} containing the tree path elements
+ */
+function getTreePath(helper, msg) {
+	var uri = msg.getRequestHeader().getURI()
+	print("getTreePath " + uri + " path=" + uri.getPath())
+	return null
+}
+
